#
# spec file for package python-pykka
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define modname pykka
%define skip_python36 1
Name:           python-pykka
Version:        4.0.2
Release:        1.2
Summary:        A Python implementation of the actor model
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/jodal/pykka
Source:         https://files.pythonhosted.org/packages/source/p/%{modname}/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Provides:       python-Pykka < %{version}-%{release}
Obsoletes:      python-Pykka = %{version}-%{release}
%python_subpackages

%description
Pykka is a Python implementation of the `actor model
<http://en.wikipedia.org/wiki/Actor_model>`_. The actor model introduces some
rules to control the sharing of state and cooperation between execution
units, with which one can build concurrent applications.

%prep
%autosetup -p1 -n %{modname}-%{version}

rm -v docs/_build/.gitignore

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md docs/
%{python_sitelib}/pykka
%{python_sitelib}/pykka-%{version}*-info

%changelog
* Thu Feb 22 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.2:
  * Make `get_all()` generic over the futures' type.
  * Format with `ruff format` instead of `black`.
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.1:
  * Update test suite to pass on Python 3.12 (#207)
- update to 4.0.0:
  * Require `block` and `timeout` arguments to always be keyword
    arguments. (PR: #198)
  * Remove support for Python 3.7. It reached end-of-life in June
    2023. (PR: #190)
  * Type hints: All typing stubs have been inlined in the source
    code and have been greatly improved. They are now tested
    using both Mypy and Pyright. (PR: #192, #193, #195)
  * Type hints: Due to the dynamic nature of `ActorProxy`
    objects, it is impossible to automatically type them
    correctly. `pykka.typing` is a new module with helpers for
    manually typing `ActorProxy` objects. Check out the docs for
    how to use the helpers. (PR: #199)
  * Linting: Replace flake8, isort, and friends with ruff
* Sat May 28 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.1.1:
  - Installs from the source tarball using the setup.py file
    generated by Poetry installed setup.cfg and tox.ini into
    site-packages. The workaround for this was to simply not
    include those files in the source tarball. (Fixes:
    gh#jodal/pykka#172)
* Fri May 27 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.1.0:
  - Remove support for Python 3.6. It reached end-of-life in
    December 2021.
  - Include docs, examples, and tests in the source
    release.
  - Require mypy 0.960 and use the latest typing features, as
    these seem to work nicely even on Python 3.7, given that the
    typing information is in separate *.pyi files and that you
    have a recent mypy version.
* Fri May 27 2022 Matej Cepl <mcepl@suse.com>
- Follow the upstream and rename Pykka to pykka.
- Update to 3.0.2:
  - Add support for Python 3.10. Tests are now run on Python 3.10
    too. No other changes required.
  - Minor reorganization of docs.
  - Use SPDX identifier for license in project metadata.
  - Remove upper version boundary for importlib_metadata.
  - Remove support for Python 2.7. It reached end-of-life in
    January 2020.
  - Remove support for Python 3.5. It reached end-of-life in
    September 2020.
  - Remove support for running actors on top of eventlet. This
    was deprecated in Pykka 2.0.3.
  - Remove support for running actors on top of gevent. This was
    deprecated in Pykka 2.0.3
  - Remove support for automatically upgrading the internal
    message format used by Pykka < 2.0 to the message types used
    by Pykka >= 2.0.
  - Include complete type hint stubs for all public APIs in the
    PyPI distribution.
  - Remove PyPy from the test matrix. There are no known changes
    that should cause Pykka to stop working on PyPy, but we will
    no longer spend any effort to keep CI for PyPy running.
  - Mark eventlet and gevent support as deprecated. The support
    will be removed in Pykka 3.0.
  - These were somewhat interesting ways to implement concurrency
    in Python when Pykka was conceived in 2011. Today, it is
    unclear it these libraries still have any mindshare or if
    keeping the support for them just adds an unnecessary burden
    to Pykka's maintenance.
  - Include Python 3.9 in the test matrix.
  - Add missing None default value for the timeout keyword
    argument to pykka.eventlet.EventletEvent.wait(), so that it
    matches the threading.Event API.
* Mon Dec  2 2019 Matej Cepl <mcepl@suse.com>
- Update to 2.0.2:
  - Make :class:`~pykka.ActorRef` hashable
  - Fix test suite run with pytest-mocker >= 1.11.2.
* Tue May 21 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 2.0.0
- enable tests
* Wed Dec 19 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description. Avoid name repetition in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Jan 10 2018 tbechtold@suse.com
- Convert to singlespec
* Wed Jan 10 2018 tbechtold@suse.com
- Initial packaging (version 1.2.1)
